@@ -27,6 +27,7 @@
 #include "pythoncompletionobject.h"
 #include "pythonkeywords.h"
 #include "pythonutils.h"
+#include "settings.h"
 
 #include <QDebug>
 #include <QDir>
@@ -47,11 +48,9 @@ const QChar recordSep(30);
 const QChar unitSep(31);
 const QChar messageEnd = 29;
 
-PythonSession::PythonSession(Cantor::Backend* backend, int pythonVersion, const QString serverName)
+PythonSession::PythonSession(Cantor::Backend* backend)
     : Session(backend)
     , m_process(nullptr)
-    , serverName(serverName)
-    , m_pythonVersion(pythonVersion)
 {
     setVariableModel(new PythonVariableModel(this));
 }
@@ -77,7 +76,12 @@ void PythonSession::login()
     m_process = new QProcess(this);
     m_process->setProcessChannelMode(QProcess::ForwardedErrorChannel);
 
-    m_process->start(QStandardPaths::findExecutable(serverName));
+#ifdef Q_OS_WIN
+	// On Windows QProcess can't handle paths with spaces, so add escaping
+	m_process->start(QLatin1String("\"") + PythonSettings::pythonServerPath().toLocalFile() + QLatin1String("\""));
+#else
+    m_process->start(PythonSettings::pythonServerPath().toLocalFile());
+#endif
 
     m_process->waitForStarted();
     m_process->waitForReadyRead();
@@ -96,11 +100,11 @@ void PythonSession::login()
 
     sendCommand(QLatin1String("login"));
     QString dir;
-    if (!worksheetPath.isEmpty())
-        dir = QFileInfo(worksheetPath).absoluteDir().absolutePath();
-    sendCommand(QLatin1String("setFilePath"), QStringList() << worksheetPath << dir);
+    if (!m_worksheetPath.isEmpty())
+        dir = QFileInfo(m_worksheetPath).absoluteDir().absolutePath();
+    sendCommand(QLatin1String("setFilePath"), QStringList() << m_worksheetPath << dir);
 
-    const QStringList& scripts = autorunScripts();
+    const QStringList& scripts = PythonSettings::autorunScripts();
     if(!scripts.isEmpty()){
         QString autorunScripts = scripts.join(QLatin1String("\n"));
         evaluateExpression(autorunScripts, Cantor::Expression::DeleteOnFinish, true);
@@ -173,7 +177,7 @@ Cantor::Expression* PythonSession::evaluateExpression(const QString& cmd, Cantor
 
 QSyntaxHighlighter* PythonSession::syntaxHighlighter(QObject* parent)
 {
-    return new PythonHighlighter(parent, this, m_pythonVersion);
+    return new PythonHighlighter(parent, this);
 }
 
 Cantor::CompletionObject* PythonSession::completionFor(const QString& command, int index)
@@ -212,12 +216,7 @@ void PythonSession::readOutput()
     while (m_process->bytesAvailable() > 0)
     {
         const QByteArray& bytes = m_process->readAll();
-        if (m_pythonVersion == 3)
-            m_output.append(QString::fromUtf8(bytes));
-        else if (m_pythonVersion == 2)
-            m_output.append(QString::fromLocal8Bit(bytes));
-        else
-            qCritical() << "Unsupported Python version" << m_pythonVersion;
+        m_output.append(QString::fromUtf8(bytes));
     }
 
     qDebug() << "m_output: " << m_output;
@@ -257,7 +256,7 @@ void PythonSession::readOutput()
 
 void PythonSession::setWorksheetPath(const QString& path)
 {
-    worksheetPath = path;
+    m_worksheetPath = path;
 }
 
 void PythonSession::reportServerProcessError(QProcess::ProcessError serverError)
