@@ -37,6 +37,7 @@
 #include <QDebug>
 #include <KLocalizedString>
 #include <KColorScheme>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QInputDialog>
 
@@ -257,7 +258,7 @@ QJsonValue TextEntry::toJupyterJson()
             entryData = doc->toHtml();
 
             // Remove DOCTYPE from html
-            entryData.remove(QRegExp(QLatin1String("<!DOCTYPE[^>]*>\\n")));
+            entryData.remove(QRegularExpression(QStringLiteral("<!DOCTYPE[^>]*>\\n")));
 
             cantorMetadata.insert(QLatin1String("text_entry_content"), entryData);
         }
@@ -490,8 +491,10 @@ void TextEntry::layOutForWidth(qreal w, bool force)
     if (size().width() == w && !force)
         return;
 
-    m_textItem->setGeometry(0, 0, w);
-    setSize(QSizeF(m_textItem->width(), m_textItem->height() + VerticalMargin));
+    const qreal margin = worksheet()->isPrinting() ? 0 : RightMargin;
+
+    m_textItem->setGeometry(0, 0, w - margin);
+    setSize(QSizeF(0 + m_textItem->width() + margin, m_textItem->height() + VerticalMargin));
 }
 
 bool TextEntry::wantToEvaluate()
