@@ -22,11 +22,14 @@
 #ifndef WORKSHEET_H
 #define WORKSHEET_H
 
+
 #include <QGraphicsScene>
 #include <QDomElement>
 #include <QGraphicsLinearLayout>
 #include <QSyntaxHighlighter>
 #include <QGraphicsRectItem>
+#include <QVector>
+#include <QQueue>
 
 #include <KZip>
 #include <QMenu>
@@ -127,6 +130,8 @@ class Worksheet : public QGraphicsScene
     void setType(Worksheet::Type type);
     Worksheet::Type type() const;
 
+    void notifyEntryFocus(WorksheetEntry* entry);
+
     // richtext
     struct RichTextInfo {
         bool bold;
@@ -258,6 +263,8 @@ class Worksheet : public QGraphicsScene
 
     QJsonDocument toJupyterJson();
 
+    bool isValidEntry(WorksheetEntry*);
+
   private Q_SLOTS:
     void showCompletion();
     //void checkEntriesForSanity();
@@ -266,6 +273,12 @@ class Worksheet : public QGraphicsScene
     WorksheetEntry* insertEntry(int type, WorksheetEntry* current = nullptr);
     WorksheetEntry* insertEntryBefore(int type, WorksheetEntry* current = nullptr);
 
+    //Actions for selection
+    void selectionRemove();
+    void selectionEvaluate();
+    void selectionMoveUp();
+    void selectionMoveDown();
+
     void animateEntryCursor();
 
   private:
@@ -335,6 +348,9 @@ class Worksheet : public QGraphicsScene
 
     QString m_backendName;
     QJsonObject* m_jupyterMetadata{nullptr};
+
+    QVector<WorksheetEntry*> m_selectedEntries;
+    QQueue<WorksheetEntry*> m_circularFocusBuffer;
 };
 
 #endif // WORKSHEET_H
